using System;
using System.Xml.Serialization;
using System.ComponentModel;

namespace EQIA.EQIDL
{
    public partial class Listbox : Control
    {
        private bool myOwnerDraw;
        private ListboxColumn[] myColumns;

        [XmlElement("Columns", IsNullable = false)]
        [Browsable(true), Description("Columns that make up this listbox")]
        public ListboxColumn[] Columns { get { return myColumns; } set { myColumns = value; } }

        [XmlElement("OwnerDraw", IsNullable = false)]
        [Browsable(true), Description("This object draws its columns itself")]
        public bool OwnerDraw { get { return myOwnerDraw; } set { myOwnerDraw = value; } }

        public Listbox() : this(null) { }
        public Listbox(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            Listbox temp_Listbox = obj as Listbox;
            if (temp_Listbox != null)
            {
                Columns = temp_Listbox.Columns;
                OwnerDraw = temp_Listbox.OwnerDraw;
            }
        }
    }

    public partial class ListboxColumn : Class
    {
        private string myHeader, myHeading, myDataType;
        private int myWidth;
        private bool mySortable;

        [XmlElement("Header", IsNullable = false)]
        [Browsable(true), Description("A special frame for the heading of this list's column")]
        public string Header { get { return myHeader; } set { myHeader = value; } }

        [XmlElement("Heading", IsNullable = false)]
        [Browsable(true), Description("The text for the heading of the list's column")]
        public string Heading { get { return myHeading; } set { myHeading = value; } }

        [XmlElement("Width", IsNullable = false)]
        [Browsable(true), Description("Width of this column")]
        public int Width { get { return myWidth; } set { myWidth = value; } }

        [XmlElement("Sortable", IsNullable = false)]
        [Browsable(true), Description("Specifies if this list be sortable")]
        public bool Sortable { get { return mySortable; } set { mySortable = value; } }

        [XmlElement("DataType", IsNullable = false)]
        [Browsable(true), Description("Not used by EQ")]
        public string DataType { get { return myDataType; } set { myDataType = value; } }

        public ListboxColumn() : this(null) { }
        public ListboxColumn(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            ListboxColumn temp_ListboxColumn = obj as ListboxColumn;
            if (temp_ListboxColumn != null)
            {
                Header = temp_ListboxColumn.Header;
                Heading = temp_ListboxColumn.Heading;
                Width = temp_ListboxColumn.Width;
                Sortable = temp_ListboxColumn.Sortable;
                DataType = temp_ListboxColumn.DataType;
            }
        }
    }
}
